\name{anova.gllm}
\alias{anova.gllm}
\title{Summarize multiple results from gllm}
\description{
Compare likelihood ratio test statistics from multiple calls to \code{gllm}.
}
\usage{
anova.gllm(object, ..., test=c("Chisq","none")) 
}
\arguments{
  \item{object}{is an object output from gllm.}
  \item{...}{other objects from gllm.}
  \item{test}{evaluate LRTS for model, or nothing.}
}
\values{ 
  A list with components:
  \item{Model} {name of each object being compared}
  \item{Resid.df} {residual degrees of freedom for each model}
  \item{Deviance} {likelihood ratio test statistic for model versus saturated model}
  \item{Pr.Fit} {chi-square based P-value for model}
  \item{Test} {models compared in stepwise testing}
  \item{Df} {degrees of freedom of model comparson}
  \item{LRtest} {likelihood ratio test statistic comparing models}
  \item{Prob} {chi-square based P-value for LRTS}
}
\keyword{ print
}

\eof
\name{as207}
\alias{as207}
\title{ Generalized log-linear modelling by EM and iterative proportional
fitting}
\description{
Fits log-linear models for incomplete contingency tables,
via an EM approach.
}
\usage{
as207(y,s,X,maxit,tol) 
}
\arguments{
  \item{y}{is the observed contingency table.}
  \item{s}{is a vector of indices, one for each cell of the full (unobserved) 
     contingency table, representing the appropriate cell of \code{y}}
  \item{X}{is the design matrix.}
  \item{maxit}{is the number of EM iterations.}
  \item{tol}{is the convergence criterion for the LR criterion.}
}
\values{ 
  A list with components:
  \item{istop} {maximum EM iterations}
  \item{ni} {nrow(X)}
  \item{nid} {nrow(X)}
  \item{nj} {length(y)}
  \item{nk} {ncol(X)-1}
  \item{nkp}{ncol(X)} 
  \item{ji} {s, the scatter vector}
  \item{y} {the observed table}
  \item{c} {the design matrix}
  \item{conv} {the convergence tolerance}
  \item{w} {work matrix}
  \item{v} {work matrix}
  \item{e} {expected counts for the full (unobserved) table}
  \item{f} {expected counts}
  \item{cspr} {Pearsonian \eqn{Chi^2}}
  \item{cslr} {Likelihood ratio \eqn{Chi^2}}
  \item{ifault} {error indicator}
}
\details{ 
The call to the slightly modified AS207 Fortran code from Haber (1984).
}
\references{
Haber M (1984).  AS207: Fitting a general log-linear model.  \emph{Appl
        Statist} 33:358-362.
}
\keyword{category}
\keyword{models}


\eof
\name{boot.gllm}
\alias{boot.gllm}
\title{ Bootstrap for generalized log-linear modelling }
\description{
Fits log-linear models for incomplete contingency tables,
including some latent class models, via EM and Fisher scoring approaches.
Performs a bootstrap for the sampling distribution of the 
full unobserved table.
}
\usage{
boot.gllm(y,s,X,method="hybrid",em.maxit=1,tol=0.00001,strata=NULL,R=200)
}
\arguments{
  \item{y}{is the observed contingency table.}
  \item{s}{is a vector of indices, one for each cell of the full (unobserved) 
     contingency table, representing the appropriate cell of \code{y}}
  \item{X}{is the design matrix, or a formula.}
  \item{method}{chooses the EM, Fisher scoring or a hybrid (EM then scoring)
     method for fitting the model.}
  \item{em.maxit}{is the number of EM iterations.}
  \item{tol}{is the convergence criterion for the LR criterion.}
  \item{strata}{is a vector identifying the sampling strata.}
  \item{R}{is the number of bootstrap replicates.}
}
\values{ 
  A matrix \eqn{R+1} by \code{ncol(X)} containing the initial estimate
  of the full (unobserved) contingency table, and the \eqn{R} bootstrap
  replicates of the full table.
}
\details{ 
The generalized log-linear model allows for modelling of incomplete
contingency tables, that is tables where one or more dimensions have
been collapsed over.  See \code{gllm} for details.

Often, functions of the full unobserved table are the main focus of the
analysis.  For example, in a double sampling design where there is a
gold standard measure for one part of the data set and only an
unreliable measure for another part, the expected value of the gold
standard in the entire dataset is the outcome of interest.  The standard
error of this statistic may be a complex function of the observed counts
and model parameters.

Bootstrapping is one way to estimate such standard errors from a complex
sampling design.  The bootstrap sampling may be stratified if the design
implies this, e.g. product-multinomial.

}
\references{
Hochberg Y (1977).  On the use of double sampling schemes in analyzing
        categorical data with misclassification errors.  \emph{J Am Statist
        Ass} 72:914-921. 
}

\examples{ 
#
# Fit Hochberg 1977 double sampling data
# 2x2 table of imprecise measures and 2x2x2x2 reliability data
#
# 2x2 table of imprecise measures
#
y1 <-c(1196, 13562,
       7151, 58175)
a2<- 2-as.integer(gl(2,1,4))
b2<- 2-as.integer(gl(2,2,4))
set1<-data.frame(y1,a2,b2)
#
# 2x2x2x2 reliability data
#
y2<-c(17, 3,   10, 258,
       3, 4,    4,  25,
      16, 3,   25, 197,
     100, 13, 107, 1014)

a <- 2-as.integer(gl(2,1,16))
a2<- 2-as.integer(gl(2,2,16))
b <- 2-as.integer(gl(2,4,16))
b2<- 2-as.integer(gl(2,8,16))

set2<-data.frame(y2,a,a2,b,b2)
#
# Combined analysis
#
y<-c(y1,y2)
#
# Map observed table onto underlying 2x2x2x2x2 table
#
s <-c(1, 1, 2, 2, 1, 1, 2, 2, 3, 3, 4, 4, 3, 3, 4, 4,
      5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20)
#
# Model combining the tables is A*A2*B*B2 + L (dummy study variable)
#
a <- 2-as.integer(gl(2,1,32))
a2<- 2-as.integer(gl(2,2,32))
b <- 2-as.integer(gl(2,4,32))
b2<- 2-as.integer(gl(2,8,32))
l <- 2-as.integer(gl(2,16,32))

X <- model.matrix( ~ a*a2*b*b2+l)

#
# Table 1 using unreliable measure
#
res1<-glm(y1 ~ a2*b2, family=poisson(),data=set1)
print(summary(res1))
#
# Table 2 using reliable measure
#
res2a<-glm(y2 ~ a*b, family=poisson(),data=set2)
print(summary(res2a))
#
# Table 2 demonstrating complex relationship between gold standard and
# unreliable measure
#
res2b<-glm(y2 ~ a*a2*b*b2, family=poisson(),data=set2)
print(summary(res2b))
#
# Combined analysis
#
require(gllm)
res12<-gllm(y,s,X)
print(summary.gllm(res12))
#
# Bootstrap the collapsed table to get estimated OR for reliable measures
#
# a and b are binary vectors the length of the *full* table
# and define the variables for which the odds ratio is to be
# estimated, here the reliable measure of injury and seatbelt usage.
#
boot.hochberg <- function (y,s,X,nrep,a,b) {
  z<-boot.gllm(y,s,X,R=nrep)
  boot.tab<-cbind(apply(z[,a & b],1,sum),
                  apply(z[,!a & b],1,sum),
                  apply(z[,a & !b],1,sum),
                  apply(z[,!a & !b],1,sum))
  oddsr<-boot.tab[,1]*boot.tab[,4]/boot.tab[,2]/boot.tab[,3] 
  hochberg.tab<-data.frame( c("yes","yes","no","no"),
                            c("yes","no","yes","no"),
                            boot.tab[1,],
                            apply(boot.tab[2:(1+nrep),],2,sd))
  colnames(hochberg.tab)<-c("Precise Injury","Precise seatbelt usage",
                            "Estimated Count","Bootstrap S.E.")
  print(hochberg.tab)
  cat("\nEstimated OR=",oddsr[1],"\n")
  cat("        Bias=",oddsr[1]-mean(oddsr[2:(1+nrep)]),"\n")
  cat("Bootstrap SE=",sd(oddsr[2:(1+nrep)]),"\n\nQuantiles\n\n")
  quantile(oddsr[2:(1+nrep)],c(0.025,0.50,0.975))
}
boot.hochberg(y,s,X,nrep=20,a,b)
}
\keyword{category}
\keyword{models}

\eof
\name{boot.table}
\alias{boot.table}
\title{Produce one bootstrap replicate of a vector of counts}
\description{
Given a vector of counts from a contingency table, produce a bootstrap 
replicate.  Sampling zeroes are replaced by 0.5.
}
\usage{
boot.table(y,strata=NULL) 
}
\arguments{
  \item{y}{is the observed contingency table.}
  \item{strata}{is a vector defining the strata for a stratified bootstrap.}
}
\values{ 
  A vector of counts with the same total.
}
\examples{
boot.table(c(1,3,4,2))
## 0.5 2.0 5.0 3.0
boot.table(c(1,3,4,2),c(1,2,1,2))
## 2 1 3 4
}
\keyword{category}
\keyword{manip}

\eof
\name{emgllm}
\alias{emgllm}
\title{ Generalized log-linear modelling by EM and iterative proportional
fitting}
\description{
Fits log-linear models for incomplete contingency tables,
including some latent class models, via an EM approach.
}
\usage{
emgllm(y,s,X,maxit=1000,tol=0.0000001) 
}
\arguments{
  \item{y}{is the observed contingency table.}
  \item{s}{is a vector of indices, one for each cell of the full (unobserved) 
     contingency table, representing the appropriate cell of \code{y}}
  \item{X}{is the design matrix, or a formula.}
  \item{maxit}{is the number of EM iterations.}
  \item{tol}{is the convergence criterion for the LR criterion.}
}
\values{ 
  A list with components:
  \item{deviance} {the final model deviance (-2 log likelihood)}
  \item{observed.values} {the observed counts in \code{y}}
  \item{fitted.values} {the expected counts under the fitted model}
  \item{full.table} {the expected counts for the full (unobserved) table.}
}
\details{ 
The generalized log-linear model allows for modelling of incomplete
contingency tables, that is tables where one or more dimensions have
been collapsed over.  These include situations where imprecise
measures have been calibrated using a "perfect" gold standard, and the
true association between imperfectly measured variables is to be
estimated; where data is missing for a subsample of the population;
latent variable models where latent variables are "errorless" functions
of observed variables - eg ML gene frequency estimation from counts of
observed phenotypes; specialised measurement models eg where observed
counts are mixtures due to perfect measures and error prone measures;
standard latent class analysis; symmetry and quasi-symmetry models for
square tables.
  
The general framework underlying these models is summarised by Espeland
(1986), and Espeland & Hui (1987), and is originally due to Thompson &
Baker (1981).  An observed contingency table \eqn{y}, which will be
treated as a vector, is modelled as arising from an underlying complete
table \eqn{z}, where observed count \eqn{y_j} is the sum of a number of
elements of \eqn{z}, such that each \eqn{z_i} contributes to no more
than one \eqn{y_j}. Therefore one can write \eqn{y=F'z}, where \eqn{F}
is made up of orthogonal columns of ones and zeros.

We then specify a loglinear model for \eqn{z}, so that
\eqn{log(E(z))=X'b}, where \eqn{X} is a design matrix, and \eqn{b} a
vector of loglinear parameters.  The loglinear model for \eqn{z} and
thus \eqn{y}, can be fitted via an iterative proportional fitting algorithm
for \eqn{b} and \eqn{z}, with an EM fitting for \eqn{y}, \eqn{z} and
\eqn{b} (Haber 1984).  

The \code{emgllm} function is a wrapper for the slightly modified AS207
Fortran code from Haber (1984).
}
\references{
Espeland MA (1986).  A general class of models for discrete multivariate
        data. \emph{Commun. Statist.-Simula} 15:405-424.

Espeland MA, Hui SL (1987).  A general approach to analyzing epidemiologic
        data that contains misclassification errors.  \emph{Biometrics}
        43:1001-1012.

Haber M (1984).  AS207: Fitting a general log-linear model.  \emph{Appl
        Statist} 33:358-362.

Thompson R, Baker RJ (1981).  Composite link functions in generalized
        linear models.  \emph{Appl Stat} 30: 125-131.
}

\examples{ 
#
# latent class analysis: two latent classes
#
# Data matrix 2x2x2x2x2 table of responses to five binary items
#
y<-c( 3,   6,   2,   11,   1,   1,   3,    4,
      1,   8,   0,   16,   0,   3,   2,   15,
     10,  29,  14,   81,   3,  28,  15,   80,
     16,  56,  21,  173,  11,  61,  28,  298)
#
# Scatter matrix: full table is 2x2x2x2x2x2
#
s<-  c(1:32,1:32)
#
# Design matrix: x is the latent variable (2 levels), 
# a-e are the observed variables
#
i<-rep(1,64)
x<-as.integer(gl(2,32,64))-1
a<-as.integer(gl(2,16,64))-1
b<-as.integer(gl(2,8 ,64))-1
c<-as.integer(gl(2,4 ,64))-1
d<-as.integer(gl(2,2 ,64))-1
e<-as.integer(gl(2,1 ,64))-1
X<-cbind(i,x,a,b,c,d,e,x*cbind(a,b,c,d,e))
colnames(X)<-c("Int","X","A","B","C","D","E","AX","BX","CX","DX","EX")
res<-emgllm(y,s,X, tol=0.01)
res
#
# Obtain standard errors for parameter estimates
#
summary(scoregllm(y,s,X,as.array(res$full.table)))
}
\keyword{category}
\keyword{models}

\eof
\name{gllm}
\alias{gllm}
\title{ Generalized log-linear modelling }
\description{
Fits log-linear models for incomplete contingency tables,
including some latent class models, via EM and Fisher scoring approaches.
}
\usage{
gllm(y,s,X,method="hybrid",em.maxit=1,tol=0.00001)
}
\arguments{
  \item{y}{is the observed contingency table.}
  \item{s}{is a vector of indices, one for each cell of the full (unobserved) 
     contingency table, representing the appropriate cell of \code{y}}
  \item{X}{is the design matrix, or a formula.}
  \item{method}{chooses the EM, Fisher scoring or a hybrid (EM then scoring)
     method for fitting the model.}
  \item{em.maxit}{is the number of EM iterations.}
  \item{tol}{is the convergence criterion for the LR criterion.}
}
\values{ 
  A list with components:
  \item{iter} {the number of scoring iterations until convergence}
  \item{deviance} {the final model deviance (-2 log likelihood)}
  \item{df} {the model degrees of freedom}
  \item{coefficients} {the model parameter estimates}
  \item{se} {the standard errors for the model parameter estimates}
  \item{V} {the variance-covariance matrix for the model parameter estimates}
  \item{observed.values} {the observed counts in \code{y}}
  \item{fitted.values} {the expected counts under the fitted model}
  \item{residuals} {Pearsonian residuals under the fitted model}
  \item{full.table} {the expected counts for the full (unobserved) table.}
}
\details{ 
The generalized log-linear model allows for modelling of incomplete
contingency tables, that is tables where one or more dimensions have
been collapsed over.  These include situations where imprecise
measures have been calibrated using a "perfect" gold standard, and the
true association between imperfectly measured variables is to be
estimated; where data is missing for a subsample of the population;
latent variable models where latent variables are "errorless" functions
of observed variables - eg ML gene frequency estimation from counts of
observed phenotypes; specialised measurement models eg where observed
counts are mixtures due to perfect measures and error prone measures;
standard latent class analysis; symmetry and quasi-symmetry models for
square tables.
  
The general framework underlying these models is summarised by Espeland
(1986), and Espeland & Hui (1987), and is originally due to Thompson &
Baker (1981).  An observed contingency table \eqn{y}, which will be
treated as a vector, is modelled as arising from an underlying complete
table \eqn{z}, where observed count \eqn{y_j} is the sum of a number of
elements of \eqn{z}, such that each \eqn{z_i} contributes to no more
than one \eqn{y_j}. Therefore one can write \eqn{y=F'z}, where \eqn{F}
is made up of orthogonal columns of ones and zeros.

We then specify a loglinear model for \eqn{z}, so that
\eqn{log(E(z))=X'b}, where \eqn{X} is a design matrix, and \eqn{b} a
vector of loglinear parameters.  The loglinear model for \eqn{z} and
thus \eqn{y}, can be fitted using two methods, both of which are
available in \code{gllm}.  The first was presented as AS207 by Michael
Haber (1984) and combines an iterative proportional fitting algorithm
for \eqn{b} and \eqn{z}, with an EM fitting for \eqn{y}, \eqn{z} and
\eqn{b}.  The second is a Fisher scoring approach, presented in Espeland
(1986).

The \code{gllm} function is actually a simple wrapper for \code{scoregllm()}.
}
\references{
Espeland MA (1986).  A general class of models for discrete multivariate
        data. \emph{Commun. Statist.-Simula} 15:405-424.

Espeland MA, Hui SL (1987).  A general approach to analyzing epidemiologic
        data that contains misclassification errors.  \emph{Biometrics}
        43:1001-1012.

Haber M (1984).  AS207: Fitting a general log-linear model.  \emph{Appl
        Statist} 33:358-362.

Thompson R, Baker RJ (1981).  Composite link functions in generalized
        linear models.  \emph{Appl Statist} 30: 125-131.
}

\examples{ 
#
# latent class analysis: two latent classes
#
# Data matrix 2x2x2x2x2 table of responses to five binary items
# (items 11-15 of sections 6-7 of the Law School Admission Test)
#
y<-c( 3,   6,   2,   11,   1,   1,   3,    4,
      1,   8,   0,   16,   0,   3,   2,   15,
     10,  29,  14,   81,   3,  28,  15,   80,
     16,  56,  21,  173,  11,  61,  28,  298)
#
# Scatter matrix: full table is 2x2x2x2x2x2
#
s<-  c(1:32,1:32)
#
# Design matrix: x is the latent variable (2 levels), 
# a-e are the observed variables
#
x<-as.integer(gl(2,32,64))-1
a<-as.integer(gl(2,16,64))-1
b<-as.integer(gl(2,8 ,64))-1
c<-as.integer(gl(2,4 ,64))-1
d<-as.integer(gl(2,2 ,64))-1
e<-as.integer(gl(2,1 ,64))-1

res1<-gllm(y,s,~x*(a+b+c+d+e),method="em",tol=0.01)
res1
#
# An example of model fitting: gametic association between two diallelic loci
#
# Data matrix
#
y<-c( 187,386,156,
      352,310,20,
      136,0  ,0)
#
# Scatter matrix
#
s<-  c( 1, 2, 2, 3,
        4, 5, 5, 6,
        4, 5, 5, 6,
        7, 8, 8, 9)
#
# Design matrix
#
X<-  matrix(c( 1,0,0,0,0,0,1,
               1,0,1,0,0,0,0,
               1,0,1,0,0,0,0,
               1,0,2,0,1,0,0,
               1,1,0,0,0,0,0,
               1,1,1,0,0,1,0,
               1,1,1,0,0,0,1,
               1,1,2,0,1,1,1,
               1,1,0,0,0,0,0,
               1,1,1,0,0,0,1,
               1,1,1,0,0,1,0,
               1,1,2,0,1,1,1,
               1,2,0,1,0,0,0,
               1,2,1,1,0,1,1,
               1,2,1,1,0,1,1,
               1,2,2,1,1,2,2), byrow=TRUE, ncol=7) 

colnames(X)<-c("Intercept", "A", "B", "P1", "P2", "Delta", "Epsilon")
res2<-gllm(y,s,X[,c(1:6)],method="hybrid",em.maxit=1,tol=0.00001)
res2
#

}
\keyword{category}
\keyword{models}

\eof
%
% file gllm/hildesheim.Rd
%
\name{hildesheim}
\alias{hildesheim}
\title{Invasive Cervical Cancer v exposure to Herpes Simplex Virus
}
\description{
The case-control study of Hildesheim et al (1991)
has been reanalysed by several authors (Carroll et al 1993;
Spiegelhalter et al 1999; Prescott et al 2002).  Exposure to Herpes
Simplex Virus in cases suffering from invasive cervical cancer and in
unaffected controls was assessed by Western Blot in all cases and
controls and by a gold-standard refined Western blotting in a subset of 115
subjects.
}

\usage{data(hildesheim)}

\format{A data frame table.}

\source{
Hildesheim et al (1991)  Herpes simplex virus type 2: A possible interaction
with human papillomavirus types 16/18 in the development of invasive cervical
cancer.  \emph{Int J Cancer}  \bold{49}, 335-340.
}

\references{
Carroll NJ, Gail MH, Lubin JH (1993)  Case-control studies with errors in
covariates. \emph{J Am Statist Assoc} \bold{88}, 185-199.

Prescott GJ, Garthwaite PH (2002)  A simple bayesian analysis of misclassified
binary data with a validation substudy.  \emph{Biometrics} \bold{58}, 454-458.

Spiegelhalter DJ, Thomas A, Best NG (1999)  Win-Bugs, Version 1.2.  Technical
Report.  Cambridge: UK.
}

\examples{
data(hildesheim)
ftable(xtabs(Freq ~ case+HSV.inac+HSV.gold, hildesheim))
fisher.test(xtabs(Freq ~ case+HSV.inac, hildesheim))
fisher.test(xtabs(Freq ~ case+HSV.gold, hildesheim, subset=HSV.gold!="?"))

#
# Combined analysis (ordered as incomplete then complete data)
#
y<-hildesheim$Freq[c(3,9,6,12,1,2,7,8,4,5,10,11)]
#
# Map observed table onto underlying 2x2x2x2 table
#
s <-c(1, 1, 2, 2, 3, 3, 4, 4,
      5, 6, 7, 8, 9, 10, 11, 12)
#
substudy  <- 2-as.integer(gl(2,8,16))
hsv.inac  <- 2-as.integer(gl(2,4,16))
hsv.gold  <- 2-as.integer(gl(2,2,16))
cancer    <- 2-as.integer(gl(2,1,16))

require(gllm)
res<-gllm(y,s, ~substudy+hsv.inac*hsv.gold*cancer)
print(summary.gllm(res))
#
# Bootstrap the collapsed table to get estimated OR for reliable measures
#
# a and b are binary vectors the length of the *full* table
# and define the variables for which the odds ratio is to be
# estimated, here the reliable measure of HSV exposure and Ca Cx
#
boot.hildesheim <- function (y,s,X,nrep,a,b) {
  z<-boot.gllm(y,s,X,R=nrep)
  boot.tab<-cbind(apply(z[,a & b],1,sum),
                  apply(z[,!a & b],1,sum),
                  apply(z[,a & !b],1,sum),
                  apply(z[,!a & !b],1,sum))
  oddsr<-boot.tab[,1]*boot.tab[,4]/boot.tab[,2]/boot.tab[,3] 
  hildesheim.tab<-data.frame( c("yes","yes","no","no"),
                              c("yes","no","yes","no"),
                              boot.tab[1,],
                              apply(boot.tab[2:(1+nrep),],2,sd))
  colnames(hildesheim.tab)<-c("Precise HSV","Cervical Cancer",
                            "Estimated Count","Bootstrap S.E.")
  print(hildesheim.tab)
  cat("\nEstimated OR=",oddsr[1],"\n")
  cat("        Bias=",oddsr[1]-mean(oddsr[2:(1+nrep)]),"\n")
  cat("Bootstrap SE=",sd(oddsr[2:(1+nrep)]),"\n\nQuantiles\n\n")
  print(quantile(oddsr[2:(1+nrep)],c(0.025,0.50,0.975)))

  b<-mean(log(oddsr[2:(1+nrep)]))
  se<-sd(log(oddsr[2:(1+nrep)]))
  ztest<-b/se
  cat("\n      Estimated log(OR)=",log(oddsr[1]),"\n",
      "Bootstrap mean log(OR)=",b,"\n",
      "          Bootstrap SE=",se,"\n",
      "                Wald Z=",ztest," (P=",2*pnorm(ztest,lower=FALSE),")\n")
}
boot.hildesheim(y,s,~substudy+hsv.inac*hsv.gold*cancer,nrep=50,cancer,hsv.gold)

}

\keyword{datasets}

\eof
\name{ld2}
\alias{ld2}
\alias{print.ld2}
\title{Estimate linkage disequilibrium between two codominant autosomal loci}
\description{
Fits a log-linear model for allelic association between two codominant
autosomal loci.  Measures of LD are odds ratios.
}
\usage{
ld2(locus1, locus2) 
}
\arguments{
  \item{locus1}{is a character vector containing the genotypes at the first
     locus, or a RxC contingency table of genotype counts.}
  \item{locus2}{is a character vector containing the genotypes at the second
     locus.}
}
\values{ 
  \item{m0} {base model}
  \item{m1} {estimating LD coefficient(s) assuming HWE}
  \item{m2} {testing HWE at locus 1}
  \item{m3} {testing HWE at locus 2}
  \item{m4} {estimating LD and HWD coefficient(s)}
}
\examples{
MNS<-matrix(c(91,32,5,147,78,17,85,75,7), nr=3)
colnames(MNS)<-c("S/S","S/s","s/s")
rownames(MNS)<-c("M/M","M/N","N/N")
class(MNS)<-"table"
print(MNS)
res<-ld2(MNS)
print(res)
}
\keyword{category}
\keyword{models}

\eof
\name{ld2.model}
\alias{ld2.model}
\title{Write design and filter matrices for log-linear model of
  linkage disequilibrium between two codominant autosomal loci}
\description{Write design and filter matrices for log-linear model of
  linkage disequilibrium between two codominant autosomal loci.
}
\usage{
ld2.model(nall1, nall2, formula="~a1+a2+p1+p2+d") 
}
\arguments{
  \item{nall1}{is number of alleles at first codominant locus.}
  \item{nall2}{is number of alleles at first codominant locus.}
  \item{formula}{is character string listing terms to be 
     included in model, where a1 denotes allele frequencies for locus 1,
     p1 the deviation from Hardy-Weinberg expectations for locus1,
     and d the intragametic allelic association parameters.}
}
\values{ 
  A list with components:
  \item{Geno}{is a dummy contingency table showing the expected order.}
  \item{s}{is a vector of indices, one for each cell of the full (unobserved) 
     contingency table, representing the appropriate cell of \code{y}}
  \item{X}{is the design matrix.}
}
\examples{
}
\keyword{category}
\keyword{models}

\eof
% file gllm/lsat.Rd
%
\name{lsat}
\alias{lsat}
\title{
Five dichotomous items from the Law School Admission Test (LSAT)
}
\description{
Small dataset (items 11-15 from sections 6 and 7 of the Law School Admission
Test) used by Bock and Lieberman (1970), Christoffersson (1975)
and Joreskog and Sorbom (1986) to test methods for factor analysis
of binary data.
}

\source{
Bock RD, Lieberman M (1970).  Fitting a response model for n dichotomously
scored items.
\emph{Psychometrika}
\bold{35}, 179-197.
}
\keyword{datasets}

\eof
\name{print.summary.gllm}
\alias{print.summary.gllm}
\title{Print results of gllm}
\description{
Print contents of result of call to \code{gllm}.
}
\usage{
print.summary.gllm(x,digits=NULL,show.residuals=FALSE,...) 
}
\arguments{
  \item{x}{is the object output from gllm.}
  \item{digits}{is the number of output digits.}
  \item{show.residuals}{toggles printing of the fitted values and residuals.}
  \item{...}{Additional arguments to be passed to \code{print.generic}.}
}
\keyword{ print
}

\eof
\name{scatter}
\alias{scatter}
\title{Create a filter matrix from a summary array of indices}
\description{
Create a filter matrix that multiplying the vector of counts from a 
complete contingency table, gives a collapsed contingency table.
}
\usage{
scatter(y,s) 
}
\arguments{
  \item{y}{is the observed contingency table. Provides a target length only.}
  \item{s}{is a vector of indices, one for each cell of the full (unobserved) 
     contingency table, representing the appropriate cell of \code{y}}
}
\values{ 
  \item{S} {A matrix of orthogonal columns of 1s and 0s}
}
\examples{
y<-double(3)
z<-1:5
z \%*\% scatter(y,c(1,1,2,3,3))
## 1+2, 3, 4+5
}
\keyword{ manip
}

\eof
\name{scoregllm}
\alias{scoregllm}
\title{ Generalized log-linear modelling via Fisher scoring }
\description{
Fits log-linear models for incomplete contingency tables,
including some latent class models, via Fisher scoring approaches.
}
\usage{
scoregllm(y,s,X,m,tol=1e-8)
}
\arguments{
  \item{y}{is the observed contingency table.}
  \item{s}{is a vector of indices, one for each cell of the full (unobserved) 
     contingency table, representing the appropriate cell of \code{y}}
  \item{X}{is the design matrix or a formula.}
  \item{m}{is a vector of starting values for the full (unobserved)
     contingency table.}
  \item{tol}{is the convergence criterion for the LR criterion.}
}
\values{ 
  A list with components:
  \item{iter} {the number of scoring iterations until convergence}
  \item{deviance} {the final model deviance (-2 log likelihood)}
  \item{df} {the model degrees of freedom}
  \item{coefficients} {the model parameter estimates}
  \item{se} {the standard errors for the model parameter estimates}
  \item{V} {the variance-covariance matrix for the model parameter estimates}
  \item{observed.values} {the observed counts in \code{y}}
  \item{fitted.values} {the expected counts under the fitted model}
  \item{residuals} {Pearsonian residuals under the fitted model}
  \item{full.table} {the expected counts for the full (unobserved) table.}
}
\details{ 
The generalized log-linear model allows for modelling of incomplete
contingency tables, that is tables where one or more dimensions have
been collapsed over.  These include situations where imprecise
measures have been calibrated using a "perfect" gold standard, and the
true association between imperfectly measured variables is to be
estimated; where data is missing for a subsample of the population;
latent variable models where latent variables are "errorless" functions
of observed variables - eg ML gene frequency estimation from counts of
observed phenotypes; specialised measurement models eg where observed
counts are mixtures due to perfect measures and error prone measures;
standard latent class analysis; symmetry and quasi-symmetry models for
square tables.
  
The general framework underlying these models is summarised by Espeland
(1986), and Espeland & Hui (1987), and is originally due to Thompson &
Baker (1981).  An observed contingency table \eqn{y}, which will be
treated as a vector, is modelled as arising from an underlying complete
table \eqn{z}, where observed count \eqn{y_j} is the sum of a number of
elements of \eqn{z}, such that each \eqn{z_i} contributes to no more
than one \eqn{y_j}. Therefore one can write \eqn{y=F'z}, where \eqn{F}
is made up of orthogonal columns of ones and zeros.

We then specify a loglinear model for \eqn{z}, so that
\eqn{log(E(z))=X'b}, where \eqn{X} is a design matrix, and \eqn{b} a
vector of loglinear parameters.  The loglinear model for \eqn{z} and
thus \eqn{y}, can be fitted by a Fisher scoring approach, presented in
Espeland (1986).

The \code{gllm} function is actually a simple wrapper for \code{scoregllm()}.
}
\references{
Espeland MA (1986).  A general class of models for discrete multivariate
        data. \emph{Commun. Statist.-Simula} 15:405-424.

Espeland MA, Hui SL (1987).  A general approach to analyzing epidemiologic
        data that contains misclassification errors.  \emph{Biometrics}
        43:1001-1012.

Thompson R, Baker RJ (1981).  Composite link functions in generalized
        linear models.  \emph{Appl Statist} 30: 125-131.
}

\examples{ 
#
# An example of model fitting: gametic association between two diallelic loci
# Data matrix
#
y<-c( 187,386,156,
      352,310,20,
      136,0  ,0)
#
# Scatter matrix
#
s<-  c( 1, 2, 2, 3,
        4, 5, 5, 6,
        4, 5, 5, 6,
        7, 8, 8, 9)
#
# Design matrix
#
X<-  matrix(c( 1,0,0,0,0,0,1,
               1,0,1,0,0,0,0,
               1,0,1,0,0,0,0,
               1,0,2,0,1,0,0,
               1,1,0,0,0,0,0,
               1,1,1,0,0,1,0,
               1,1,1,0,0,0,1,
               1,1,2,0,1,1,1,
               1,1,0,0,0,0,0,
               1,1,1,0,0,0,1,
               1,1,1,0,0,1,0,
               1,1,2,0,1,1,1,
               1,2,0,1,0,0,0,
               1,2,1,1,0,1,1,
               1,2,1,1,0,1,1,
               1,2,2,1,1,2,2), byrow=TRUE, ncol=7) 

colnames(X)<-c("Intercept", "A", "B", "P1", "P2", "Delta", "Epsilon")
res<-scoregllm(y,s,X[,c(1:6)], 
               c(255,176,176,121,164,37,113,25,164,113,37,25,90,20,20,5))
summary(res)
#

}
\keyword{ models }
\keyword{ category }

\eof
\name{summary.gllm}
\alias{summary.gllm}
\title{Summarize results of gllm}
\description{
Summarizes contents of result of call to \code{gllm}.
}
\usage{
summary.gllm(object,...) 
}
\arguments{
  \item{object}{is the object output from gllm.}
  \item{...}{other arguments}
}
\values{ 
  A list with components:
  \item{nobs} {the number of cells in the observed table}
  \item{nfull} {the number of cells in the full table}
  \item{mean.cell} {the mean cell count in the observed table}
  \item{deviance} {the final model deviance (-2 log likelihood)}
  \item{model.df} {the model degrees of freedom}
  \item{coefficients} {the model parameter estimates, standard errors}
  \item{residuals} {Observed and fitted counts, plus Pearsonian residuals}
}
\keyword{ print
}

\eof
